@@ -83,6 +83,8 @@ seg.lm.fit<-function(y,XREG,Z,PSI,w,o,opz){
     if (ncol(V) == 1) colnames(X)[(ncol(XREG) + 1):ncol(X)] <- c("U", "V")
         else colnames(X)[(ncol(XREG) + 1):ncol(X)] <- c(paste("U", 1:ncol(U), sep = ""), paste("V", 1:ncol(V), sep = ""))
     obj <- lm.wfit(x = X, y = y, w = w, offset = o)
+    obj$epsilon <- epsilon
+    obj$it <- it
     #fino a qua..
     obj<-list(obj=obj,it=it,psi=psi,psi.values=psi.values,U=U,V=V,rangeZ=rangeZ,
         epsilon=epsilon,nomiOK=nomiOK)
